#!/bin/bash
#
# Requirements:
# - jq 1.5 or later
#   - fromdate, @tsv
# - zabbix_sender 3.0.18 or later

set -eu

export LANG=en_US.utf8
export PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
readonly CMDNAME=$(basename $0)

OPT_TIMEOUT=3
OPT_ZABBIX_AGENTD_CONF="/etc/zabbix/zabbix_agentd.conf"

zabbix_sender(){
	local json="$1"
	local hostname="$2"
	local time_str="$3"
	local exit_status=1
	local tmp_file="$(mktemp /tmp/${CMDNAME}.XXXXXX.tmp)"
	local options=""
	local item_prefix="mydata"

	# zabbix hostname is allow whitespace.
	hostname="\\\"${hostname}\\\""

	local keys=$(echo "${json}" | jq -r '.[0].stats[].metrics | keys | join(" ")')
	for key in $keys; do
		echo "${json}" | jq -r ".[] | [\"${hostname}\", \"${item_prefix}.${key}\", (.date + \"${time_str}\" | fromdate | tostring), (.stats[].metrics.${key} | tostring)] | join(\" \")" >> $tmp_file
	done

	set +e
	result=$(timeout $OPT_TIMEOUT zabbix_sender -c $OPT_ZABBIX_AGENTD_CONF -T -i $tmp_file $options)
	exit_status=$?
	set -e

#	rm -f "${tmp_file}"

	echo $exit_status
	exit $exit_status
}

json='[{"date":"2019-12-10","stats":[{"metrics":{"blocks":0,"bounces":1,"delivered":9,"processed":9,"requests":10,"spam_reports":0}}]},{"date":"2019-12-11","stats":[{"metrics":{"blocks":0,"bounces":2,"delivered":18,"processed":18,"requests":20,"spam_reports":0}}]}]'
time_str="T00:00:00Z"
hostname="localhost"

zabbix_sender "${json}" "${hostname}" "${time_str}"

# vim: ts=4:sw=4
